@@ -320,11 +320,24 @@ gdm_server_resolve_command_line (GdmServer  *server,
                 argv[len++] = g_strdup (server->priv->display_seat_id);
         }
 
+        /* If we were compiled with Xserver >= 1.17 we need to specify
+         * '-listen tcp' as the X server dosen't listen on tcp sockets
+         * by default anymore. In older versions we need to pass
+         * -nolisten tcp to disable listening on tcp sockets.
+         */
+#ifdef HAVE_XSERVER_THAT_DEFAULTS_TO_LOCAL_ONLY
+        if (!server->priv->disable_tcp && ! query_in_arglist) {
+                argv[len++] = g_strdup ("-listen");
+                argv[len++] = g_strdup ("tcp");
+        }
+#else
         if (server->priv->disable_tcp && ! query_in_arglist) {
                 argv[len++] = g_strdup ("-nolisten");
                 argv[len++] = g_strdup ("tcp");
         }
 
+#endif
+
         if (vtarg != NULL && ! gotvtarg) {
                 argv[len++] = g_strdup (vtarg);
         }
@@ -375,7 +388,7 @@ change_user (GdmServer *server)
 
         gdm_get_pwent_for_name (server->priv->user_name, &pwent);
         if (pwent == NULL) {
-                g_warning (_("Server was to be spawned by user %s but that user doesn't exist"),
+                g_warning (_("Server was to be spawned by user %s but that user doesn’t exist"),
                            server->priv->user_name);
                 _exit (1);
         }
@@ -386,7 +399,7 @@ change_user (GdmServer *server)
 
         if (pwent->pw_uid != 0) {
                 if (setgid (pwent->pw_gid) < 0)  {
-                        g_warning (_("Couldn't set groupid to %d"),
+                        g_warning (_("Couldn’t set groupid to %d"),
                                    pwent->pw_gid);
                         _exit (1);
                 }
@@ -398,7 +411,7 @@ change_user (GdmServer *server)
                 }
 
                 if (setuid (pwent->pw_uid) < 0)  {
-                        g_warning (_("Couldn't set userid to %d"),
+                        g_warning (_("Couldn’t set userid to %d"),
                                    (int)pwent->pw_uid);
                         _exit (1);
                 }
@@ -406,7 +419,7 @@ change_user (GdmServer *server)
                 gid_t groups[1] = { 0 };
 
                 if (setgid (0) < 0)  {
-                        g_warning (_("Couldn't set groupid to %d"), 0);
+                        g_warning (_("Couldn’t set groupid to %d"), 0);
                         /* Don't error out, it's not fatal, if it fails we'll
                          * just still be */
                 }
@@ -529,7 +542,7 @@ server_child_setup (GdmServer *server)
 
         if (server->priv->priority != 0) {
                 if (setpriority (PRIO_PROCESS, 0, server->priv->priority)) {
-                        g_warning (_("%s: Server priority couldn't be set to %d: %s"),
+                        g_warning (_("%s: Server priority couldn’t be set to %d: %s"),
                                    "gdm_server_spawn",
                                    server->priv->priority,
                                    g_strerror (errno));
